import helper from "./QA-handle/helper"
import sinon from "sinon"

// 以a作为参考点，b的长度不能小于a
const isSameValueType = (a, b) => {
  const aPath = []
  const bPath = []

  const isObject = (v) => {
    return typeof v === "object" && v !== null
  }

  const getValueType = (v) => {
    if (Array.isArray(v)) return "array"
    if (isObject(v)) return "object"
    if (v === null) return null
    return typeof v
  }

  const check = (a, b) => {
    if (Array.isArray(a) && Array.isArray(b)) {
      if (a.length > b.length) {
        return false
      }

      let i = 0,
        l = a.length
      while (i < l) {
        const result = check(a[i], b[i])
        if (!result) {
          aPath.push("index:" + i + "," + "value:" + getValueType(a[i]))
          bPath.push("index:" + i + "," + "value:" + getValueType(b[i]))
          return false
        }

        i++
      }

      return true
    } else if (isObject(a) && isObject(b)) {
      if (Object.keys(a).length > Object.keys(b).length) {
        aPath.push("key length:" + a.length)
        bPath.push("key length:" + b.length)
        return false
      }

      for (const key in a) {
        const result = check(a[key], b[key])

        if (!result) {
          aPath.push("key:" + key + "," + "value:" + getValueType(a[key]))
          bPath.push("key:" + key + "," + "value:" + getValueType(b[key]))
          return false
        }
      }

      return true
    } else {
      return typeof a === typeof b
    }
  }

  const res = check(a, b)
  return [res, aPath.reverse(), bPath.reverse()]
}

const assert = (returnValue, expectValue) => {
  // 已期望值为基准
  const [pass, aPath, bPath] = isSameValueType(expectValue, returnValue)
  if (!pass) {
    let errMsg = "断言失败，实际值与期望值的类型不匹配" + "\n"

    if (aPath.length) {
      errMsg +=
        "期望：" +
        JSON.stringify(aPath, null, 2) +
        "\n" +
        "实际：" +
        JSON.stringify(bPath, null, 2)
    }

    throw new Error(errMsg)
  }
}

function tryGetFn(fnGetter) {
  try {
    const fn = fnGetter()
    if (typeof fn !== "function") {
      throw new Error("skiped - fn is not a function")
    } else {
      return fn
    }
  } catch (err) {
    throw new Error("skiped - not found fn")
  }
}

function resolveFnExcuteResult(
  excutor,
  excutorWrapper,
  args,
  expectValue,
  done
) {
  let res

  // excutorWrapper mark api error that occured itself in sync or async
  try {
    res = excutor.apply(null, args)
    if (res instanceof Promise) {
      res
        .then((result) => {
          excutorWrapper.excutorReturns.push(result)
          try {
            assert(result, expectValue)
            done()
          } catch (e) {
            done(e)
          }
        })
        .catch((e) => {
          excutorWrapper.excutorReturns.push(e)
          done(e)
        })
    } else {
      excutorWrapper.excutorReturns.push(res)
      assert(res, expectValue) // mocha will catch error in sync, we no need to do it.
      done()
    }
  } catch (e) {
    excutorWrapper.excutorReturns.push(e)
    done(e)
  }
}

function transfromDeps(deps = [], cb) {
  return deps.map((apiName) => {
    const apiConfig = apiMark[apiName]
    if (!apiConfig)
      throw new Error(
        "The api name of " + apiName + " was not found in apiMark"
      )
    return cb(apiConfig.value, apiName)
  })
}

function shouldExistTaseCase(targetPath, apiQueue) {
  // 先检查它是不是自身
  if (apiQueue.find((api) => targetPath === api.path)) {
    return true
  }

  // 再检查它是不是依赖
  const depsArray = apiQueue.reduce((acc, item) => {
    acc = acc.concat(item.ref.deps)
    return acc
  }, [])

  return depsArray.find((dep) => dep === targetPath)
}

export const apiMark = {
  "context.leadSubscribe": {
    key: "context.leadSubscribe",
    value:
      // created by ApiCallNode
      (function create_leadSubscribe_0_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.context.leadSubscribe)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _leadSubscribe_0_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_leadSubscribe_0_Wrapper"

        return wrapperFn
      })(),
  },
  "context.getGiftConf": {
    key: "context.getGiftConf",
    value:
      // created by ApiCallNode
      (function create_getGiftConf_1_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.context.getGiftConf)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getGiftConf_1_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getGiftConf_1_Wrapper"

        return wrapperFn
      })(),
  },
  "context.sendGift": {
    key: "context.sendGift",
    value:
      // created by ApiCallNode
      (function create_sendGift_2_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.context.sendGift)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _sendGift_2_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = ["context.getGiftConf"]
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_sendGift_2_Wrapper"

        return wrapperFn
      })(),
  },
  "context.leadGift": {
    key: "context.leadGift",
    value:
      // created by ApiCallNode
      (function create_leadGift_3_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.context.leadGift)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _leadGift_3_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_leadGift_3_Wrapper"

        return wrapperFn
      })(),
  },
  "context.leadBarrage": {
    key: "context.leadBarrage",
    value:
      // created by ApiCallNode
      (function create_leadBarrage_4_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.context.leadBarrage)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _leadBarrage_4_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_leadBarrage_4_Wrapper"

        return wrapperFn
      })(),
  },
  "context.share": {
    key: "context.share",
    value:
      // created by ApiCallNode
      (function create_share_5_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.context.share)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _share_5_Wrapper(args, expectValue, next) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_share_5_Wrapper"

        return wrapperFn
      })(),
  },
  "device.startAudioRecording": {
    key: "device.startAudioRecording",
    value:
      // created by ApiCallNode
      (function create_startAudioRecording_6_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.device.startAudioRecording)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _startAudioRecording_6_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_startAudioRecording_6_Wrapper"

        return wrapperFn
      })(),
  },
  "device.finishAudioRecording": {
    key: "device.finishAudioRecording",
    value:
      // created by ApiCallNode
      (function create_finishAudioRecording_7_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.device.finishAudioRecording)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _finishAudioRecording_7_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_finishAudioRecording_7_Wrapper"

        return wrapperFn
      })(),
  },
  "fs.uploadImg": {
    key: "fs.uploadImg",
    value:
      // created by ApiCallNode
      (function create_uploadImg_8_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.fs.uploadImg)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _uploadImg_8_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_uploadImg_8_Wrapper"

        return wrapperFn
      })(),
  },
  "fs.offlineFileReady": {
    key: "fs.offlineFileReady",
    value:
      // created by ApiCallNode
      (function create_offlineFileReady_9_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.fs.offlineFileReady)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _offlineFileReady_9_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_offlineFileReady_9_Wrapper"

        return wrapperFn
      })(),
  },
  "fs.uploadFile": {
    key: "fs.uploadFile",
    value:
      // created by ApiCallNode
      (function create_uploadFile_10_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.fs.uploadFile)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _uploadFile_10_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_uploadFile_10_Wrapper"

        return wrapperFn
      })(),
  },
  "fs.downloadBatchRes": {
    key: "fs.downloadBatchRes",
    value:
      // created by ApiCallNode
      (function create_downloadBatchRes_11_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.fs.downloadBatchRes)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _downloadBatchRes_11_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_downloadBatchRes_11_Wrapper"

        return wrapperFn
      })(),
  },
  "fs.removeRes": {
    key: "fs.removeRes",
    value:
      // created by ApiCallNode
      (function create_removeRes_12_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.fs.removeRes)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeRes_12_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeRes_12_Wrapper"

        return wrapperFn
      })(),
  },
  "link.createLinkMicRoom": {
    key: "link.createLinkMicRoom",
    value:
      // created by ApiCallNode
      (function create_createLinkMicRoom_13_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.createLinkMicRoom)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _createLinkMicRoom_13_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_createLinkMicRoom_13_Wrapper"

        return wrapperFn
      })(),
  },
  "link.joinLinkMicRoom": {
    key: "link.joinLinkMicRoom",
    value:
      // created by ApiCallNode
      (function create_joinLinkMicRoom_14_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.joinLinkMicRoom)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _joinLinkMicRoom_14_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_joinLinkMicRoom_14_Wrapper"

        return wrapperFn
      })(),
  },
  "link.leaveLinkMicRoom": {
    key: "link.leaveLinkMicRoom",
    value:
      // created by ApiCallNode
      (function create_leaveLinkMicRoom_15_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.leaveLinkMicRoom)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _leaveLinkMicRoom_15_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_leaveLinkMicRoom_15_Wrapper"

        return wrapperFn
      })(),
  },
  "link.startPublishAudio": {
    key: "link.startPublishAudio",
    value:
      // created by ApiCallNode
      (function create_startPublishAudio_16_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.startPublishAudio)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _startPublishAudio_16_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_startPublishAudio_16_Wrapper"

        return wrapperFn
      })(),
  },
  "link.stopPublishAudio": {
    key: "link.stopPublishAudio",
    value:
      // created by ApiCallNode
      (function create_stopPublishAudio_17_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.stopPublishAudio)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _stopPublishAudio_17_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_stopPublishAudio_17_Wrapper"

        return wrapperFn
      })(),
  },
  "link.setMicVolume": {
    key: "link.setMicVolume",
    value:
      // created by ApiCallNode
      (function create_setMicVolume_18_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.setMicVolume)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setMicVolume_18_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setMicVolume_18_Wrapper"

        return wrapperFn
      })(),
  },
  "link.updateAudioPlay": {
    key: "link.updateAudioPlay",
    value:
      // created by ApiCallNode
      (function create_updateAudioPlay_19_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.updateAudioPlay)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _updateAudioPlay_19_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_updateAudioPlay_19_Wrapper"

        return wrapperFn
      })(),
  },
  "link.onAudioStreamNameChange": {
    key: "link.onAudioStreamNameChange",
    value:
      // created by ApiCallNode
      (function create_onAudioStreamNameChange_20_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.onAudioStreamNameChange)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _onAudioStreamNameChange_20_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_onAudioStreamNameChange_20_Wrapper"

        return wrapperFn
      })(),
  },
  "link.offAudioStreamNameChange": {
    key: "link.offAudioStreamNameChange",
    value:
      // created by ApiCallNode
      (function create_offAudioStreamNameChange_21_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.link.offAudioStreamNameChange)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _offAudioStreamNameChange_21_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_offAudioStreamNameChange_21_Wrapper"

        return wrapperFn
      })(),
  },
  "panel.setLayout": {
    key: "panel.setLayout",
    value:
      // created by ApiCallNode
      (function create_setLayout_22_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.panel.setLayout)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setLayout_22_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setLayout_22_Wrapper"

        return wrapperFn
      })(),
  },
  "player.tapped": {
    key: "player.tapped",
    value:
      // created by ApiCallNode
      (function create_tapped_23_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.tapped)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _tapped_23_Wrapper(args, expectValue, next) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_tapped_23_Wrapper"

        return wrapperFn
      })(),
  },
  "player.doubleTapped": {
    key: "player.doubleTapped",
    value:
      // created by ApiCallNode
      (function create_doubleTapped_24_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.doubleTapped)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _doubleTapped_24_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_doubleTapped_24_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getFrameData": {
    key: "player.getFrameData",
    value:
      // created by ApiCallNode
      (function create_getFrameData_25_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getFrameData)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getFrameData_25_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getFrameData_25_Wrapper"

        return wrapperFn
      })(),
  },
  "player.on": {
    key: "player.on",
    value:
      // created by ApiCallNode
      (function create_on_26_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.on)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _on_26_Wrapper(args, expectValue, next) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_on_26_Wrapper"

        return wrapperFn
      })(),
  },
  "player.off": {
    key: "player.off",
    value:
      // created by ApiCallNode
      (function create_off_27_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.off)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _off_27_Wrapper(args, expectValue, next) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_off_27_Wrapper"

        return wrapperFn
      })(),
  },
  "player.switchLine": {
    key: "player.switchLine",
    value:
      // created by ApiCallNode
      (function create_switchLine_28_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.switchLine)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _switchLine_28_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_switchLine_28_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getLinesInfo": {
    key: "player.getLinesInfo",
    value:
      // created by ApiCallNode
      (function create_getLinesInfo_29_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getLinesInfo)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getLinesInfo_29_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getLinesInfo_29_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getCurrentLine": {
    key: "player.getCurrentLine",
    value:
      // created by ApiCallNode
      (function create_getCurrentLine_30_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getCurrentLine)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getCurrentLine_30_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getCurrentLine_30_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getVideoInfo": {
    key: "player.getVideoInfo",
    value:
      // created by ApiCallNode
      (function create_getVideoInfo_31_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getVideoInfo)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getVideoInfo_31_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getVideoInfo_31_Wrapper"

        return wrapperFn
      })(),
  },
  "player.playVideo": {
    key: "player.playVideo",
    value:
      // created by ApiCallNode
      (function create_playVideo_32_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.playVideo)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _playVideo_32_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_playVideo_32_Wrapper"

        return wrapperFn
      })(),
  },
  "player.fastForward": {
    key: "player.fastForward",
    value:
      // created by ApiCallNode
      (function create_fastForward_33_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.fastForward)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _fastForward_33_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_fastForward_33_Wrapper"

        return wrapperFn
      })(),
  },
  "player.fastBackward": {
    key: "player.fastBackward",
    value:
      // created by ApiCallNode
      (function create_fastBackward_34_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.fastBackward)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _fastBackward_34_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_fastBackward_34_Wrapper"

        return wrapperFn
      })(),
  },
  "player.resumeLive": {
    key: "player.resumeLive",
    value:
      // created by ApiCallNode
      (function create_resumeLive_35_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.resumeLive)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _resumeLive_35_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_resumeLive_35_Wrapper"

        return wrapperFn
      })(),
  },
  "player.setViewport": {
    key: "player.setViewport",
    value:
      // created by ApiCallNode
      (function create_setViewport_36_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.setViewport)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setViewport_36_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setViewport_36_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getViewport": {
    key: "player.getViewport",
    value:
      // created by ApiCallNode
      (function create_getViewport_37_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getViewport)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getViewport_37_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getViewport_37_Wrapper"

        return wrapperFn
      })(),
  },
  "player.addViewport": {
    key: "player.addViewport",
    value:
      // created by ApiCallNode
      (function create_addViewport_38_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.addViewport)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addViewport_38_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addViewport_38_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getVideoPosition": {
    key: "player.getVideoPosition",
    value:
      // created by ApiCallNode
      (function create_getVideoPosition_39_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getVideoPosition)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getVideoPosition_39_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getVideoPosition_39_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getVideoState": {
    key: "player.getVideoState",
    value:
      // created by ApiCallNode
      (function create_getVideoState_40_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getVideoState)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getVideoState_40_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getVideoState_40_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getLayoutInfo": {
    key: "player.getLayoutInfo",
    value:
      // created by ApiCallNode
      (function create_getLayoutInfo_41_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getLayoutInfo)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getLayoutInfo_41_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getLayoutInfo_41_Wrapper"

        return wrapperFn
      })(),
  },
  "player.setBufferTime": {
    key: "player.setBufferTime",
    value:
      // created by ApiCallNode
      (function create_setBufferTime_42_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.setBufferTime)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setBufferTime_42_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setBufferTime_42_Wrapper"

        return wrapperFn
      })(),
  },
  "player.contextMenu": {
    key: "player.contextMenu",
    value:
      // created by ApiCallNode
      (function create_contextMenu_43_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.contextMenu)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _contextMenu_43_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_contextMenu_43_Wrapper"

        return wrapperFn
      })(),
  },
  "player.playLive": {
    key: "player.playLive",
    value:
      // created by ApiCallNode
      (function create_playLive_44_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.playLive)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _playLive_44_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_playLive_44_Wrapper"

        return wrapperFn
      })(),
  },
  "player.getVolume": {
    key: "player.getVolume",
    value:
      // created by ApiCallNode
      (function create_getVolume_45_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.getVolume)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getVolume_45_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getVolume_45_Wrapper"

        return wrapperFn
      })(),
  },
  "player.setVolume": {
    key: "player.setVolume",
    value:
      // created by ApiCallNode
      (function create_setVolume_46_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.setVolume)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setVolume_46_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setVolume_46_Wrapper"

        return wrapperFn
      })(),
  },
  "player.mutePlay": {
    key: "player.mutePlay",
    value:
      // created by ApiCallNode
      (function create_mutePlay_47_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.mutePlay)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _mutePlay_47_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_mutePlay_47_Wrapper"

        return wrapperFn
      })(),
  },
  "player.unmutePlay": {
    key: "player.unmutePlay",
    value:
      // created by ApiCallNode
      (function create_unmutePlay_48_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.player.unmutePlay)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _unmutePlay_48_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_unmutePlay_48_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.getViewerLatencyMode": {
    key: "stream.getViewerLatencyMode",
    value:
      // created by ApiCallNode
      (function create_getViewerLatencyMode_49_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.getViewerLatencyMode)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getViewerLatencyMode_49_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getViewerLatencyMode_49_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.setViewerLatencyMode": {
    key: "stream.setViewerLatencyMode",
    value:
      // created by ApiCallNode
      (function create_setViewerLatencyMode_50_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.setViewerLatencyMode)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setViewerLatencyMode_50_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setViewerLatencyMode_50_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addExtraWhiteBoard": {
    key: "stream.addExtraWhiteBoard",
    value:
      // created by ApiCallNode
      (function create_addExtraWhiteBoard_51_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addExtraWhiteBoard)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addExtraWhiteBoard_51_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addExtraWhiteBoard_51_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.removeExtraWhiteBoard": {
    key: "stream.removeExtraWhiteBoard",
    value:
      // created by ApiCallNode
      (function create_removeExtraWhiteBoard_52_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.removeExtraWhiteBoard)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeExtraWhiteBoard_52_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeExtraWhiteBoard_52_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.sendToExtraWhiteBoard": {
    key: "stream.sendToExtraWhiteBoard",
    value:
      // created by ApiCallNode
      (function create_sendToExtraWhiteBoard_53_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.sendToExtraWhiteBoard)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _sendToExtraWhiteBoard_53_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_sendToExtraWhiteBoard_53_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.getStreamResolution": {
    key: "stream.getStreamResolution",
    value:
      // created by ApiCallNode
      (function create_getStreamResolution_54_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.getStreamResolution)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getStreamResolution_54_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getStreamResolution_54_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.setStreamResolution": {
    key: "stream.setStreamResolution",
    value:
      // created by ApiCallNode
      (function create_setStreamResolution_55_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.setStreamResolution)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setStreamResolution_55_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setStreamResolution_55_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.getStreamerLatencyMode": {
    key: "stream.getStreamerLatencyMode",
    value:
      // created by ApiCallNode
      (function create_getStreamerLatencyMode_56_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.getStreamerLatencyMode)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getStreamerLatencyMode_56_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getStreamerLatencyMode_56_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.setStreamerLatencyMode": {
    key: "stream.setStreamerLatencyMode",
    value:
      // created by ApiCallNode
      (function create_setStreamerLatencyMode_57_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.setStreamerLatencyMode)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setStreamerLatencyMode_57_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setStreamerLatencyMode_57_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addLayers": {
    key: "stream.addLayers",
    value:
      // created by ApiCallNode
      (function create_addLayers_58_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addLayers)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addLayers_58_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addLayers_58_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.getLayers": {
    key: "stream.getLayers",
    value:
      // created by ApiCallNode
      (function create_getLayers_59_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.getLayers)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getLayers_59_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getLayers_59_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.updateLayers": {
    key: "stream.updateLayers",
    value:
      // created by ApiCallNode
      (function create_updateLayers_60_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.updateLayers)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _updateLayers_60_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_updateLayers_60_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.removeLayers": {
    key: "stream.removeLayers",
    value:
      // created by ApiCallNode
      (function create_removeLayers_61_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.removeLayers)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeLayers_61_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeLayers_61_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addWhiteBoard": {
    key: "stream.addWhiteBoard",
    value:
      // created by ApiCallNode
      (function create_addWhiteBoard_62_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addWhiteBoard)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addWhiteBoard_62_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addWhiteBoard_62_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.removeWhiteBoard": {
    key: "stream.removeWhiteBoard",
    value:
      // created by ApiCallNode
      (function create_removeWhiteBoard_63_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.removeWhiteBoard)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeWhiteBoard_63_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeWhiteBoard_63_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addImageLayer": {
    key: "stream.addImageLayer",
    value:
      // created by ApiCallNode
      (function create_addImageLayer_64_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addImageLayer)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addImageLayer_64_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addImageLayer_64_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.removeImageLayer": {
    key: "stream.removeImageLayer",
    value:
      // created by ApiCallNode
      (function create_removeImageLayer_65_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.removeImageLayer)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeImageLayer_65_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeImageLayer_65_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.enableFaceEffect": {
    key: "stream.enableFaceEffect",
    value:
      // created by ApiCallNode
      (function create_enableFaceEffect_66_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.enableFaceEffect)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _enableFaceEffect_66_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_enableFaceEffect_66_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.onExtraWhiteBoardMessage": {
    key: "stream.onExtraWhiteBoardMessage",
    value:
      // created by ApiCallNode
      (function create_onExtraWhiteBoardMessage_67_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.onExtraWhiteBoardMessage)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _onExtraWhiteBoardMessage_67_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_onExtraWhiteBoardMessage_67_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addTextLayer": {
    key: "stream.addTextLayer",
    value:
      // created by ApiCallNode
      (function create_addTextLayer_68_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addTextLayer)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addTextLayer_68_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addTextLayer_68_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.enableBackgroundSegmentation": {
    key: "stream.enableBackgroundSegmentation",
    value:
      // created by ApiCallNode
      (function create_enableBackgroundSegmentation_69_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(
            () => global.hyExt.stream.enableBackgroundSegmentation
          )
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _enableBackgroundSegmentation_69_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_enableBackgroundSegmentation_69_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.disableBackgroundSegmentation": {
    key: "stream.disableBackgroundSegmentation",
    value:
      // created by ApiCallNode
      (function create_disableBackgroundSegmentation_70_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(
            () => global.hyExt.stream.disableBackgroundSegmentation
          )
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _disableBackgroundSegmentation_70_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_disableBackgroundSegmentation_70_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.createWB": {
    key: "stream.createWB",
    value:
      // created by ApiCallNode
      (function create_createWB_71_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.createWB)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _createWB_71_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_createWB_71_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.deleteWB": {
    key: "stream.deleteWB",
    value:
      // created by ApiCallNode
      (function create_deleteWB_72_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.deleteWB)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _deleteWB_72_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_deleteWB_72_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.onLayerLayoutChange": {
    key: "stream.onLayerLayoutChange",
    value:
      // created by ApiCallNode
      (function create_onLayerLayoutChange_73_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.onLayerLayoutChange)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _onLayerLayoutChange_73_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_onLayerLayoutChange_73_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.getStreamCanvasLayout": {
    key: "stream.getStreamCanvasLayout",
    value:
      // created by ApiCallNode
      (function create_getStreamCanvasLayout_74_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.getStreamCanvasLayout)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getStreamCanvasLayout_74_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getStreamCanvasLayout_74_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.setStreamCanvasLayout": {
    key: "stream.setStreamCanvasLayout",
    value:
      // created by ApiCallNode
      (function create_setStreamCanvasLayout_75_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.setStreamCanvasLayout)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setStreamCanvasLayout_75_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setStreamCanvasLayout_75_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addLayer": {
    key: "stream.addLayer",
    value:
      // created by ApiCallNode
      (function create_addLayer_76_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addLayer)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addLayer_76_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addLayer_76_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.updateLayer": {
    key: "stream.updateLayer",
    value:
      // created by ApiCallNode
      (function create_updateLayer_77_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.updateLayer)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _updateLayer_77_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_updateLayer_77_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.removeLayer": {
    key: "stream.removeLayer",
    value:
      // created by ApiCallNode
      (function create_removeLayer_78_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.removeLayer)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeLayer_78_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeLayer_78_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.addEffect": {
    key: "stream.addEffect",
    value:
      // created by ApiCallNode
      (function create_addEffect_79_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.addEffect)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _addEffect_79_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_addEffect_79_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.removeEffect": {
    key: "stream.removeEffect",
    value:
      // created by ApiCallNode
      (function create_removeEffect_80_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.removeEffect)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _removeEffect_80_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_removeEffect_80_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.getStreamingInfo": {
    key: "stream.getStreamingInfo",
    value:
      // created by ApiCallNode
      (function create_getStreamingInfo_81_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.getStreamingInfo)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _getStreamingInfo_81_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_getStreamingInfo_81_Wrapper"

        return wrapperFn
      })(),
  },
  "stream.setWBEditMode": {
    key: "stream.setWBEditMode",
    value:
      // created by ApiCallNode
      (function create_setWBEditMode_82_WrapperFn() {
        let rawFn
        try {
          rawFn = tryGetFn(() => global.hyExt.stream.setWBEditMode)
        } catch (err) {
          rawFn = function deliverError() {
            throw err
          }
        }

        const spyFn = sinon.spy(rawFn)
        const wrapperFn = function _setWBEditMode_82_Wrapper(
          args,
          expectValue,
          next
        ) {
          wrapperFn.expects.push(helper.v2type(expectValue))
          resolveFnExcuteResult(spyFn, wrapperFn, args, expectValue, next)
        }

        // expose some api to outside
        wrapperFn.excutor = spyFn
        wrapperFn.deps = []
        wrapperFn.expects = [] // 放置的是期望类型
        wrapperFn.excutorReturns = []
        wrapperFn.id = "_setWBEditMode_82_Wrapper"

        return wrapperFn
      })(),
  },
}
export const hostContext = {
  mocha: { timeout: 8000 },
  projectName: "qa-effect",
}

export function injectTestSuite(apiQueue) {
  describe("QA testing", () => {
    shouldExistTaseCase("context.getGiftConf", apiQueue) &&
      it("No.1 $[context.getGiftConf] - 第1个测试用例", (done) => {
        const testRunner = apiMark["context.getGiftConf"].value
        const doneCb = done

        const args = []
        const expectValue = [
          {
            giftId: 0,
            giftName: "",
            giftLogo: "",
            giftGif: "",
            giftPriceHuya: 0,
            giftPriceGreenBean: 0,
            giftPriceWhiteBean: 0,
          },
        ]

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.setWBEditMode", apiQueue) &&
      it("No.2 $[stream.setWBEditMode] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.setWBEditMode"].value
        const doneCb = done

        const args = [{ enable: false }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.getStreamingInfo", apiQueue) &&
      it("No.3 $[stream.getStreamingInfo] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.getStreamingInfo"].value
        const doneCb = done

        const args = [{ keys: [""] }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.removeEffect", apiQueue) &&
      it("No.4 $[stream.removeEffect] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.removeEffect"].value
        const doneCb = done

        const args = [{ md5: "", fileName: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addEffect", apiQueue) &&
      it("No.5 $[stream.addEffect] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addEffect"].value
        const doneCb = done

        const args = [{ md5: "", fileName: "", param: {} }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.removeLayer", apiQueue) &&
      it("No.6 $[stream.removeLayer] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.removeLayer"].value
        const doneCb = done

        const args = [{ layerId: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.updateLayer", apiQueue) &&
      it("No.7 $[stream.updateLayer] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.updateLayer"].value
        const doneCb = done

        const args = [
          {
            layerId: "",
            offsetX: 0,
            offsetY: 0,
            canvasWidth: 0,
            canvasHeight: 0,
            weight: 0,
            force: false,
            param: {},
          },
        ]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addLayer", apiQueue) &&
      it("No.8 $[stream.addLayer] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addLayer"].value
        const doneCb = done

        const args = [
          {
            type: "",
            layerName: "",
            offsetX: 0,
            offsetY: 0,
            canvasWidth: 0,
            canvasHeight: 0,
            weight: 0,
            force: false,
            param: {},
          },
        ]
        const expectValue = { layerId: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.setStreamCanvasLayout", apiQueue) &&
      it("No.9 $[stream.setStreamCanvasLayout] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.setStreamCanvasLayout"].value
        const doneCb = done

        const args = [{ width: 0, height: 0, x: 0, y: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.getStreamCanvasLayout", apiQueue) &&
      it("No.10 $[stream.getStreamCanvasLayout] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.getStreamCanvasLayout"].value
        const doneCb = done

        const args = []
        const expectValue = { width: 0, height: 0, x: 0, y: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.onLayerLayoutChange", apiQueue) &&
      it("No.11 $[stream.onLayerLayoutChange] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.onLayerLayoutChange"].value
        const doneCb = done

        const args = [
          {
            layerId: "",
            callback: function anonymous(layoutInfo) {
              // do something
            },
          },
        ]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.deleteWB", apiQueue) &&
      it("No.12 $[stream.deleteWB] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.deleteWB"].value
        const doneCb = done

        const args = [{ wbId: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.createWB", apiQueue) &&
      it("No.13 $[stream.createWB] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.createWB"].value
        const doneCb = done

        const args = [
          {
            type: "",
            wbName: "",
            offsetX: 0,
            offsetY: 0,
            canvasWidth: 0,
            canvasHeight: 0,
            x: 0,
            y: 0,
            width: 0,
            height: 0,
            force: false,
            param: {},
          },
        ]
        const expectValue = { wbId: "" }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.disableBackgroundSegmentation", apiQueue) &&
      it("No.14 $[stream.disableBackgroundSegmentation] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.disableBackgroundSegmentation"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.enableBackgroundSegmentation", apiQueue) &&
      it("No.15 $[stream.enableBackgroundSegmentation] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.enableBackgroundSegmentation"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addTextLayer", apiQueue) &&
      it("No.16 $[stream.addTextLayer] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addTextLayer"].value
        const doneCb = done

        const args = [
          {
            layerId: "",
            text: "",
            fontFamily: "",
            fontSize: 0,
            fontColor: "",
            useBackground: false,
            backgroundColor: "",
            alpha: 0,
            bold: false,
            italic: false,
            underline: false,
            scroll: false,
          },
        ]
        const expectValue = { layerId: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.onExtraWhiteBoardMessage", apiQueue) &&
      it("No.17 $[stream.onExtraWhiteBoardMessage] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.onExtraWhiteBoardMessage"].value
        const doneCb = done

        const args = [
          {
            callback: function anonymous(data) {
              // do something
            },
          },
        ]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.enableFaceEffect", apiQueue) &&
      it("No.18 $[stream.enableFaceEffect] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.enableFaceEffect"].value
        const doneCb = done

        const args = [{ md5: "", enable: false }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.removeImageLayer", apiQueue) &&
      it("No.19 $[stream.removeImageLayer] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.removeImageLayer"].value
        const doneCb = done

        const args = [{ layerId: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addImageLayer", apiQueue) &&
      it("No.20 $[stream.addImageLayer] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addImageLayer"].value
        const doneCb = done

        const args = [{ md5: "", frameRate: 0 }]
        const expectValue = { layerId: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.removeWhiteBoard", apiQueue) &&
      it("No.21 $[stream.removeWhiteBoard] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.removeWhiteBoard"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addWhiteBoard", apiQueue) &&
      it("No.22 $[stream.addWhiteBoard] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addWhiteBoard"].value
        const doneCb = done

        const args = [{ param: { width: 0, height: 0, x: 0, y: 0 } }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.removeLayers", apiQueue) &&
      it("No.23 $[stream.removeLayers] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.removeLayers"].value
        const doneCb = done

        const args = [[{ layerId: 0 }]]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.updateLayers", apiQueue) &&
      it("No.24 $[stream.updateLayers] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.updateLayers"].value
        const doneCb = done

        const args = [
          [
            {
              layerId: "",
              offsetX: 0,
              offsetY: 0,
              canvasWidth: 0,
              canvasHeight: 0,
              weight: 0,
              force: false,
              param: {},
            },
          ],
        ]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.getLayers", apiQueue) &&
      it("No.25 $[stream.getLayers] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.getLayers"].value
        const doneCb = done

        const args = []
        const expectValue = [
          {
            type: "",
            layerName: "",
            offsetX: 0,
            offsetY: 0,
            canvasWidth: 0,
            canvasHeight: 0,
            weight: 0,
            force: false,
            param: {},
          },
        ]

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addLayers", apiQueue) &&
      it("No.26 $[stream.addLayers] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addLayers"].value
        const doneCb = done

        const args = [
          [
            {
              type: "",
              layerName: "",
              offsetX: 0,
              offsetY: 0,
              canvasWidth: 0,
              canvasHeight: 0,
              weight: 0,
              force: false,
              param: {},
            },
          ],
        ]
        const expectValue = [{ layerId: 0 }]

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.setStreamerLatencyMode", apiQueue) &&
      it("No.27 $[stream.setStreamerLatencyMode] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.setStreamerLatencyMode"].value
        const doneCb = done

        const args = [{ mode: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.getStreamerLatencyMode", apiQueue) &&
      it("No.28 $[stream.getStreamerLatencyMode] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.getStreamerLatencyMode"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.setStreamResolution", apiQueue) &&
      it("No.29 $[stream.setStreamResolution] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.setStreamResolution"].value
        const doneCb = done

        const args = [{ width: 0, height: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.getStreamResolution", apiQueue) &&
      it("No.30 $[stream.getStreamResolution] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.getStreamResolution"].value
        const doneCb = done

        const args = []
        const expectValue = { width: 0, height: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.sendToExtraWhiteBoard", apiQueue) &&
      it("No.31 $[stream.sendToExtraWhiteBoard] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.sendToExtraWhiteBoard"].value
        const doneCb = done

        const args = [{ webId: "", data: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.removeExtraWhiteBoard", apiQueue) &&
      it("No.32 $[stream.removeExtraWhiteBoard] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.removeExtraWhiteBoard"].value
        const doneCb = done

        const args = [{ wbId: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.addExtraWhiteBoard", apiQueue) &&
      it("No.33 $[stream.addExtraWhiteBoard] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.addExtraWhiteBoard"].value
        const doneCb = done

        const args = [{ param: { width: 0, height: 0 } }]
        const expectValue = { wbId: "" }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.setViewerLatencyMode", apiQueue) &&
      it("No.34 $[stream.setViewerLatencyMode] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.setViewerLatencyMode"].value
        const doneCb = done

        const args = [{ mode: 0 }]
        const expectValue = 0

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("stream.getViewerLatencyMode", apiQueue) &&
      it("No.35 $[stream.getViewerLatencyMode] - 第1个测试用例", (done) => {
        const testRunner = apiMark["stream.getViewerLatencyMode"].value
        const doneCb = done

        const args = []
        const expectValue = 0

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.unmutePlay", apiQueue) &&
      it("No.36 $[player.unmutePlay] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.unmutePlay"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.mutePlay", apiQueue) &&
      it("No.37 $[player.mutePlay] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.mutePlay"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.setVolume", apiQueue) &&
      it("No.38 $[player.setVolume] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.setVolume"].value
        const doneCb = done

        const args = [{ volume: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getVolume", apiQueue) &&
      it("No.39 $[player.getVolume] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getVolume"].value
        const doneCb = done

        const args = []
        const expectValue = { volume: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.playLive", apiQueue) &&
      it("No.40 $[player.playLive] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.playLive"].value
        const doneCb = done

        const args = [{ streamName: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.contextMenu", apiQueue) &&
      it("No.41 $[player.contextMenu] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.contextMenu"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.setBufferTime", apiQueue) &&
      it("No.42 $[player.setBufferTime] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.setBufferTime"].value
        const doneCb = done

        const args = [{ time: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getLayoutInfo", apiQueue) &&
      it("No.43 $[player.getLayoutInfo] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getLayoutInfo"].value
        const doneCb = done

        const args = []
        const expectValue = { isZoomOut: false }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getVideoState", apiQueue) &&
      it("No.44 $[player.getVideoState] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getVideoState"].value
        const doneCb = done

        const args = []
        const expectValue = { state: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getVideoPosition", apiQueue) &&
      it("No.45 $[player.getVideoPosition] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getVideoPosition"].value
        const doneCb = done

        const args = []
        const expectValue = { left: 0, top: 0, right: 0, bottom: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.addViewport", apiQueue) &&
      it("No.46 $[player.addViewport] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.addViewport"].value
        const doneCb = done

        const args = [{ x: 0, y: 0, scale: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getViewport", apiQueue) &&
      it("No.47 $[player.getViewport] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getViewport"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.setViewport", apiQueue) &&
      it("No.48 $[player.setViewport] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.setViewport"].value
        const doneCb = done

        const args = [{ x: 0, y: 0, scale: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.resumeLive", apiQueue) &&
      it("No.49 $[player.resumeLive] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.resumeLive"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.fastBackward", apiQueue) &&
      it("No.50 $[player.fastBackward] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.fastBackward"].value
        const doneCb = done

        const args = [{ time: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.fastForward", apiQueue) &&
      it("No.51 $[player.fastForward] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.fastForward"].value
        const doneCb = done

        const args = [{ time: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.playVideo", apiQueue) &&
      it("No.52 $[player.playVideo] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.playVideo"].value
        const doneCb = done

        const args = [{ url: "", startTime: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getVideoInfo", apiQueue) &&
      it("No.53 $[player.getVideoInfo] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getVideoInfo"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getCurrentLine", apiQueue) &&
      it("No.54 $[player.getCurrentLine] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getCurrentLine"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getLinesInfo", apiQueue) &&
      it("No.55 $[player.getLinesInfo] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getLinesInfo"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.switchLine", apiQueue) &&
      it("No.56 $[player.switchLine] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.switchLine"].value
        const doneCb = done

        const args = [{ line: 0 }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.off", apiQueue) &&
      it("No.57 $[player.off] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.off"].value
        const doneCb = done

        const args = ["", function anonymous() {}]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.on", apiQueue) &&
      it("No.58 $[player.on] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.on"].value
        const doneCb = done

        const args = ["", function anonymous() {}]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.getFrameData", apiQueue) &&
      it("No.59 $[player.getFrameData] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.getFrameData"].value
        const doneCb = done

        const args = []
        const expectValue = { pts: 0 }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.doubleTapped", apiQueue) &&
      it("No.60 $[player.doubleTapped] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.doubleTapped"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("player.tapped", apiQueue) &&
      it("No.61 $[player.tapped] - 第1个测试用例", (done) => {
        const testRunner = apiMark["player.tapped"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("panel.setLayout", apiQueue) &&
      it("No.62 $[panel.setLayout] - 第1个测试用例", (done) => {
        const testRunner = apiMark["panel.setLayout"].value
        const doneCb = done

        const args = [
          { visible: true, res: "PLAYER", x: 0, y: 0, width: 0, height: 0 },
        ]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.offAudioStreamNameChange", apiQueue) &&
      it("No.63 $[link.offAudioStreamNameChange] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.offAudioStreamNameChange"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.onAudioStreamNameChange", apiQueue) &&
      it("No.64 $[link.onAudioStreamNameChange] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.onAudioStreamNameChange"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.updateAudioPlay", apiQueue) &&
      it("No.65 $[link.updateAudioPlay] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.updateAudioPlay"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.setMicVolume", apiQueue) &&
      it("No.66 $[link.setMicVolume] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.setMicVolume"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.stopPublishAudio", apiQueue) &&
      it("No.67 $[link.stopPublishAudio] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.stopPublishAudio"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.startPublishAudio", apiQueue) &&
      it("No.68 $[link.startPublishAudio] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.startPublishAudio"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.leaveLinkMicRoom", apiQueue) &&
      it("No.69 $[link.leaveLinkMicRoom] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.leaveLinkMicRoom"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.joinLinkMicRoom", apiQueue) &&
      it("No.70 $[link.joinLinkMicRoom] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.joinLinkMicRoom"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("link.createLinkMicRoom", apiQueue) &&
      it("No.71 $[link.createLinkMicRoom] - 第1个测试用例", (done) => {
        const testRunner = apiMark["link.createLinkMicRoom"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("fs.removeRes", apiQueue) &&
      it("No.72 $[fs.removeRes] - 第1个测试用例", (done) => {
        const testRunner = apiMark["fs.removeRes"].value
        const doneCb = done

        const args = [{ md5: "" }]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("fs.downloadBatchRes", apiQueue) &&
      it("No.73 $[fs.downloadBatchRes] - 第1个测试用例", (done) => {
        const testRunner = apiMark["fs.downloadBatchRes"].value
        const doneCb = done

        const args = [[{ url: "", md5: "", unzip: false }]]
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("fs.uploadFile", apiQueue) &&
      it("No.74 $[fs.uploadFile] - 第1个测试用例", (done) => {
        const testRunner = apiMark["fs.uploadFile"].value
        const doneCb = done

        const args = []
        const expectValue = { url: "" }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("fs.offlineFileReady", apiQueue) &&
      it("No.75 $[fs.offlineFileReady] - 第1个测试用例", (done) => {
        const testRunner = apiMark["fs.offlineFileReady"].value
        const doneCb = done

        const args = [{}, ""]
        const expectValue = ""

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("fs.uploadImg", apiQueue) &&
      it("No.76 $[fs.uploadImg] - 第1个测试用例", (done) => {
        const testRunner = apiMark["fs.uploadImg"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("device.finishAudioRecording", apiQueue) &&
      it("No.77 $[device.finishAudioRecording] - 第1个测试用例", (done) => {
        const testRunner = apiMark["device.finishAudioRecording"].value
        const doneCb = done

        const args = []
        const expectValue = { url: "" }

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("device.startAudioRecording", apiQueue) &&
      it("No.78 $[device.startAudioRecording] - 第1个测试用例", (done) => {
        const testRunner = apiMark["device.startAudioRecording"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("context.share", apiQueue) &&
      it("No.79 $[context.share] - 第1个测试用例", (done) => {
        const testRunner = apiMark["context.share"].value
        const doneCb = done

        const args = [
          {
            platform: "",
            title: "",
            content: "",
            shareURL: "",
            imageURL: "",
            miniprogramUrl: "",
            mediaType: 0,
          },
        ]
        const expectValue = {}

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("context.leadBarrage", apiQueue) &&
      it("No.80 $[context.leadBarrage] - 第1个测试用例", (done) => {
        const testRunner = apiMark["context.leadBarrage"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("context.leadGift", apiQueue) &&
      it("No.81 $[context.leadGift] - 第1个测试用例", (done) => {
        const testRunner = apiMark["context.leadGift"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("context.sendGift", apiQueue) &&
      it("No.82 $[context.sendGift] - 第1个测试用例", (done) => {
        const testRunner = apiMark["context.sendGift"].value
        const doneCb = function doneByUserControl(e) {
          ;(function (e, next) {
            if (e) {
              if (e.message.includes("不能")) {
                next()
              } else {
                next(e)
              }
            } else {
              next()
            }
          })(...[e, done])
        }

        let deps = []

        try {
          deps = transfromDeps(
            ["context.getGiftConf"],
            (thisTestRunner, apiName) => {
              const lastReturn =
                thisTestRunner.excutorReturns[
                  thisTestRunner.excutorReturns.length - 1
                ]
              if (lastReturn instanceof Error) {
                throw new Error(
                  "The " +
                    apiName +
                    " ocurred an error, it depend on context.sendGift."
                )
              }
              return lastReturn
            }
          )
        } catch (e) {
          return doneCb(e)
        }

        const args = (function (giftConfQueue) {
          var giftConf = giftConfQueue[0]
          return [
            {
              giftCount: 1,
              giftId: giftConf.giftId,
            },
          ]
        })(...deps)
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })

    shouldExistTaseCase("context.leadSubscribe", apiQueue) &&
      it("No.83 $[context.leadSubscribe] - 第1个测试用例", (done) => {
        const testRunner = apiMark["context.leadSubscribe"].value
        const doneCb = done

        const args = []
        const expectValue = undefined

        testRunner(args, expectValue, doneCb)
      })
  })
}
